pub mod assetcache;
pub mod assetmanager;

use std::{collections::HashMap, path::Path};

use anyhow::Result;
use assetpath::AssetPath;

use crate::prelude::*;

/// recursively searches given directory for files with given suffix
pub fn search_file_names(
    directory: &AssetPath,
    suffix: &str,
) -> Result<(Vec<String>, HashMap<String, AssetPath>)> {
    let files = if directory.is_empty() {
        Vec::new()
    } else {
        search_dir_recursively(&directory.full_path(), suffix)?
    };

    let mut file_map: HashMap<String, AssetPath> = HashMap::new();
    let mut names: Vec<String> = Vec::new();

    for file in &files {
        let s = file.full_path();
        let path = Path::new(s.as_str());

        if let Some(name) = path.file_stem() {
            if let Some(name_string) = name.to_str() {
                let string = name_string.to_string();

                file_map.insert(string.clone(), file.clone());
                names.push(string);
            }
        }
    }

    Ok((names, file_map))
}
