use std::any::Any;

use crate::prelude::*;

use anyhow::Result;
use utilities::prelude::cgmath::{Vector2, Vector3};

pub trait Map: Any + Send + Sync {
    fn name(&self) -> &str;

    fn check_walkability(
        &self,
        position: Vector2<f32>,
        direction: Vector2<f32>,
        radius: f32,
    ) -> Result<bool>;

    fn get_height(&self, x: f32, y: f32) -> Result<f32>;

    fn spawn_positions(&self) -> Result<Vec<Vector3<f32>>>;
    fn leave_markers(&self) -> Result<Vec<Entity>>;

    fn disable(&self, scene: &mut Scene) -> Result<()>;
}
